﻿//---------------------------------------------------------------------------- 
//
//  Copyright (C) CSharp Labs.  All rights reserved.
// 
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions:
// 
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
// 
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//  THE SOFTWARE.
// 
// History
//  07/07/13    Created 
//
//---------------------------------------------------------------------------

namespace System.Runtime.InteropServices.Enums
{
    public enum LocalAllocFlags : uint
    {
        /// <summary>
        /// Combines LMEM_MOVEABLE and LMEM_ZEROINIT.
        /// </summary>
        LHND = 0x0042,
        /// <summary>
        /// Allocates fixed memory. The return value is a pointer to the memory object.
        /// </summary>
        LMEM_FIXED = 0x0000,
        /// <summary>
        ///  Allocates movable memory. Memory blocks are never moved in physical memory, but they can be moved within the default heap. The return value is a handle to the memory object. To translate the handle to a pointer, use the LocalLock function. This value cannot be combined with LMEM_FIXED.
        /// </summary>
        LMEM_MOVEABLE = 0x0002,
        /// <summary>
        /// Initializes memory contents to zero.
        /// </summary>
        LMEM_ZEROINIT = 0x0040,
        /// <summary>
        /// Combines LMEM_FIXED and LMEM_ZEROINIT.
        /// </summary>
        LPTR = 0x0040,
        /// <summary>
        /// Same as LMEM_MOVEABLE.
        /// </summary>
        NONZEROLHND = LMEM_MOVEABLE,
        /// <summary>
        /// Same as LMEM_FIXED.
        /// </summary>
        NONZEROLPTR = LMEM_FIXED,
    }
}
