﻿//---------------------------------------------------------------------------- 
//
//  Copyright (C) CSharp Labs.  All rights reserved.
// 
//  Permission is hereby granted, free of charge, to any person obtaining a copy
//  of this software and associated documentation files (the "Software"), to deal
//  in the Software without restriction, including without limitation the rights
//  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
//  copies of the Software, and to permit persons to whom the Software is
//  furnished to do so, subject to the following conditions:
// 
//  The above copyright notice and this permission notice shall be included in
//  all copies or substantial portions of the Software.
// 
//  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
//  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
//  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
//  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
//  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
//  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
//  THE SOFTWARE.
// 
// History
//  07/07/13    Created 
//
//---------------------------------------------------------------------------

namespace System.Windows.Forms
{
    using System.Diagnostics;
    using System.IO;
    using System.Runtime.InteropServices;
    using System.Runtime.InteropServices.Enums;
    using System.Runtime.InteropServices.Structures;
    using System.Runtime.Serialization.Formatters.Binary;

    public static class NativeDataTransfer
    {
        /// <summary>
        /// Transfers an object to a <see cref="NativeReceiveDataSink"/>.
        /// </summary>
        /// <param name="hWnd">The <see cref="NativeReceiveDataSink.Handle"/> to send to.</param>
        /// <param name="graph">The object to serialize and send.</param>
        /// <returns>true if the object was transferred; otherwise, false if <see cref="NativeMethods.SendMessageTimeout"/> failed to send within the allotted timeout.</returns>
        public static bool Transfer(IntPtr hWnd, object graph)
        {
            //create the data structure:
            COPYDATASTRUCT data = new COPYDATASTRUCT();

            //create a formatter to serialize data:
            BinaryFormatter formatter = new BinaryFormatter();

            try
            {
                //create a stream to serialize data to:
                using (MemoryStream stream = new MemoryStream())
                {
                    //serialize the object:
                    formatter.Serialize(stream, graph);

                    //set data length:
                    data.cbData = (int)stream.Length;

                    //allocate unmanaged array:
                    data.lpData = NativeMethods.LocalAlloc(Runtime.InteropServices.Enums.LocalAllocFlags.LPTR, new IntPtr(data.cbData));
                    
                    //copy data from the managed array to unmanaged array:
                    Marshal.Copy(stream.ToArray(), 0, data.lpData, data.cbData);
                }

                IntPtr result;

                //send and wait:
                return NativeMethods.SendMessageTimeout(hWnd, WindowsMessages.WM_COPYDATA, IntPtr.Zero, ref data, SendMessageTimeoutFlags.SMTO_NOTIMEOUTIFNOTHUNG, 5000, out result) != IntPtr.Zero;
            }
            finally
            {
                //destroy the unmanaged block of memory:
                data.Dispose();
            }
        }
    }
}
